import React, { useMemo } from 'react';

import { useSelector } from 'react-redux';

import { getIsFetching } from '../selectors';
import { FetchShape } from '../types';

type IProps = {
	path: string;
	placeholder?: React.ReactElement;
	shape: FetchShape;
};

const FetchLoader: React.FC<IProps> = (props) => {
	const { children, path, shape } = props;

	const isFetching = useSelector((state) => getIsFetching(state, path));

	const placeholder = useMemo(() => {
		switch (shape) {
			case FetchShape.input:
				return (
					<>
						<div className="h-4 bg-gray-200 rounded w-1/4" />
						<div className="mt-1">
							<div className="h-7 bg-gray-200 rounded" />
						</div>
					</>
				);
		}
	}, [shape]);

	return (
		<>
			{isFetching ? (
				<div className="animate-pulse flex-1 py-1">{props.placeholder || placeholder}</div>
			) : (
				children
			)}
		</>
	);
};

export default FetchLoader;
