import React, { useCallback, useEffect, useState } from 'react';

import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

import { IHTMLElement } from '@treejs/types/form';

export type ICheckboxFieldProps<V = boolean> = {
	checked?: boolean;
	label?: string;
	title: string;
} & IHTMLElement<V>;

const Checkbox: React.FC<ICheckboxFieldProps> = (props) => {
	const { title, label, name } = props;

	const [checked, setChecked] = useState(false);

	useEffect(() => {
		setChecked(props.checked);
	}, [props.checked]);

	const handleClick = useCallback(
		(e: React.MouseEvent<HTMLLabelElement>): void => {
			if (props.onChange) {
				props.onChange(!checked, e);
			}
			setChecked(!checked);
		},
		[checked]
	);

	const handleBlur = useCallback(
		(e: React.FocusEvent<HTMLInputElement>): void => {
			if (props.onBlur) {
				props.onBlur(checked, e);
			}
		},
		[checked]
	);

	return (
		<div className="relative mt-1">
			<label className="cursor-pointer text-primary" htmlFor={name} onClick={handleClick}>
				<div className="block text-black pb-2 field-label">{title}</div>
				<FontAwesomeIcon size="lg" icon={checked ? 'check-square' : 'square'} />
				<span className="ml-1 text-black">{label}</span>
			</label>
			<input id={name} name={name} className="hidden" type="checkbox" onBlur={handleBlur} />
		</div>
	);
};

export default Checkbox;
