import React from 'react';

import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import cx from 'classnames';

import { STATUS } from '@treejs/types/common';

type IProps = {
	children?: React.ReactElement | string;
	status: STATUS;
	title?: string;
};

function Message(props: IProps) {
	const { status = STATUS.none, title, children } = props;
	return (
		<div
			className={cx('message', {
				'message--none': status === STATUS.none,
				'message--info': status === STATUS.info,
				'message--success': status === STATUS.success,
				'message--warning': status === STATUS.warning,
				'message--error': status === STATUS.error,
			})}
		>
			<div className="inline-block align-middle mr-4 text-xl">
				{status === STATUS.info && <FontAwesomeIcon icon="info-circle" />}
				{status === STATUS.success && <FontAwesomeIcon icon="check-circle" />}
				{status === STATUS.warning && <FontAwesomeIcon icon="exclamation-triangle" />}
				{status === STATUS.error && <FontAwesomeIcon icon="exclamation-circle" />}
				{status === STATUS.none && <FontAwesomeIcon icon="hand-peace" />}
			</div>
			<div className="text-xl font-normal max-w-full flex-initial">
				{title}
				<div className="text-sm font-base">{children}</div>
			</div>
		</div>
	);
}

export default Message;
