import React, { useCallback, useMemo, useState } from 'react';

import OutsideClickHandler from 'react-outside-click-handler';

import { isNilOrEmpty } from '@treejs/utils';

import { IMenuItem } from '../types';

type IProps = {
	children: React.ReactElement;
	items: IMenuItem[];
	onClick: (href: string) => () => void;
};

export const UserMenu = (props: IProps) => {
	const { items, onClick, children } = props;

	const [open, setOpen] = useState(false);

	const handleClick = useCallback(
		(href: string) => () => {
			onClick(href)();
			setOpen(false);
		},
		[onClick]
	);

	const handleOutsideClick = useCallback(() => {
		setOpen(false);
	}, []);

	const handleUserMenuClick = useCallback(() => {
		setOpen(!open);
	}, [open]);

	const userItems = useMemo(() => {
		if (!isNilOrEmpty(items)) {
			return items.map(({ label, href }, i) => (
				<div key={i} className="user-item" onClick={handleClick(href)}>
					{label}
				</div>
			));
		} else {
			return null;
		}
	}, [items]);

	return (
		<OutsideClickHandler onOutsideClick={handleOutsideClick}>
			<div className="ml-4 cursor-pointer self-center" onClick={handleUserMenuClick}>
				{children}
			</div>
			<div className="absolute top-12 right-5 z-10 bg-white shadow-lg w-60">{open && userItems}</div>
		</OutsideClickHandler>
	);
};

export default UserMenu;
