import React, { useCallback, useEffect, useState } from 'react';

import { useDispatch } from 'react-redux';

import { STATUS } from '@treejs/types/common';
import { IHTMLElement } from '@treejs/types/form';

import { openModal } from '../Modal/actions';
import { addModalComponent } from '../Modal/utils';
import TextField from '../TextField';
import TimePickerModal from './components/TimePickerModal';

export type ITimePickerFieldProps<V = string> = {
	status?: STATUS;
	value?: string;
} & IHTMLElement<V>;

const TimePicker: React.FC<ITimePickerFieldProps> = (props) => {
	const { onBlur, onChange, title, status, name } = props;

	const dispatch = useDispatch();

	const [value, setValue] = useState<string>();

	useEffect(() => {
		setValue(props.value);
	}, [props.value]);

	const handleBlur = useCallback((newValue, e): void => {
		if (onBlur) {
			onBlur(newValue, e);
		}
	}, []);

	const handleTimeClick = useCallback((newValue): void => {
		setValue(newValue);
		if (onChange) {
			onChange(newValue, null);
		}
	}, []);

	const handleOpenModal = useCallback((): void => {
		addModalComponent(name, <TimePickerModal value={value} onChange={handleTimeClick} />);
		dispatch(openModal({ id: name, title, width: 300 }));
	}, [name, value, title]);

	return (
		<TextField
			name={name}
			title={title}
			onClick={handleOpenModal}
			onFocus={handleOpenModal}
			onBlur={handleBlur}
			value={value}
			status={status}
			readonly
		/>
	);
};

export default TimePicker;
