import React, { useLayoutEffect, useState } from 'react';
import { compose, is, mapObjIndexed, values } from 'ramda';

import cx from 'classnames';

import { TITLE_SPACE_ENUM } from './types';

type IProps = {
	children?: React.ReactElement | string;
	className?: string;
	direct?: TITLE_SPACE_ENUM;
	size: number | string;
	space?: Partial<Record<TITLE_SPACE_ENUM, number>>;
};

const Title = (props: IProps): React.ReactElement => {
	const { size, space = 4, children } = props;

	const [spacing, setSpacing] = useState<string[]>();

	useLayoutEffect(() => {
		setSpacing(
			compose(
				values,
				mapObjIndexed((size, direction) => {
					return `m${direction}-${size}`;
				})
			)(space)
		);
	}, [space]);

	return (
		<div className={cx(`text-${is(Number, size) ? (size > 1 ? `${size}xl` : 'xl') : size}`, spacing)}>
			{children}
		</div>
	);
};

Title.displayName = 'Title';

export default Title;
