import React from 'react';

import TimePickerField from '@treejs/forms/components/fields/TimePickerField';
import { IField } from '@treejs/forms/types';

import { FIELD_TYPE } from '../constants';
import CheckboxField from './fields/CheckboxField';
import DatePickerField from './fields/DatePickerField';
import RadioButtonField from './fields/RadioButtonField';
import SelectBoxField from './fields/SelectBoxField';
import TextField from './fields/TextField';

type IProps<F> = F & IField;

function Field<F>(props: IProps<F>) {
	const { component, ...other } = props as any;

	switch (component) {
		case FIELD_TYPE.TEXT_FIELD:
			return <TextField {...other} />;
		case FIELD_TYPE.CHECKBOX:
			return <CheckboxField {...other} />;
		case FIELD_TYPE.RADIO_BUTTON:
			return <RadioButtonField {...other} />;
		case FIELD_TYPE.SELECT_BOX:
			return <SelectBoxField {...other} />;
		case FIELD_TYPE.DATE_PICKER:
			return <DatePickerField {...other} />;
		case FIELD_TYPE.TIME_PICKER:
			return <TimePickerField {...other} />;
		default:
			return null;
	}
}

export default Field;
