import React, { useCallback, useState } from 'react';

import { useDispatch, useSelector } from 'react-redux';

import { fetchData } from '@treejs/api/actions';
import { getIsFetching } from '@treejs/api/selectors';
import { FetchMethod } from '@treejs/api/types';
import Button from '@treejs/components/Button';
import { Grid, GridCol } from '@treejs/components/Grid';
import ContentLoader from '@treejs/components/Loader';
import { STATUS } from '@treejs/types/common';
import { isNilOrEmpty } from '@treejs/utils';

import Placeholder from './Placeholder';

const URL = '/todos/1';

const getUrlKey = (method: FetchMethod) => `${URL}.${method}`;

const FetchPage = (): React.ReactElement => {
	const dispatch = useDispatch();

	const [response, setResponse] = useState({});

	const fetchPath = getUrlKey(FetchMethod.GET);

	const isFetching = useSelector((state) => getIsFetching(state, fetchPath));

	const fetch = useCallback(() => {
		dispatch(
			fetchData({
				url: URL,
				method: FetchMethod.GET,
				onSuccess: (res) => {
					setResponse(res);
				},
			})
		);
	}, []);

	return (
		<>
			<Grid cols={4}>
				<GridCol>
					<Button status={STATUS.warning} label="Odeslat" onClick={fetch} disabled={isFetching} />
				</GridCol>
			</Grid>
			<ContentLoader isLoading={isFetching} placeholder={<Placeholder />}>
				{!isNilOrEmpty(response) && <pre>{JSON.stringify(response, undefined, 2)}</pre>}
			</ContentLoader>
		</>
	);
};

export default FetchPage;
